%define build_neonxml 1
%{?_without_neonxml: %global build_neonxml 0}
%{?_with_neonxml: %global build_neonxml 1}

%define build_doc 0
%{?_without_doc: %global build_doc 0}
%{?_with_doc: %global build_doc 1}

%define	major 1
%define libname	%mklibname upsclient %{major}

%define url_ver %(echo %version | cut -d. -f1,2)

Summary:	Network UPS Tools Client Utilities
Name:		nut
Version:	2.8.0
Release:	%mkrel 1
Epoch:		1
License:	GPLv2
Group:		System/Kernel and hardware
URL:		https://www.networkupstools.org/
Source0:	https://www.networkupstools.org/source/%{url_ver}/%{name}-%{version}.tar.gz
Source3:	nut-client.tmpfiles
Source4:	libs.sh
# Mageia patches:
Patch90:		nut-upsset.conf.diff
Patch91:		nut-mdv_conf.diff
Patch92:		nut-mageia-add.patch
# FC patches:
Patch1:		nut-2.6.3-tmpfiles.patch
Requires(pre):	rpm-helper
Requires(post):	rpm-helper
Requires(postun):	rpm-helper
Requires(preun):	rpm-helper
BuildRequires:	freetype2-devel
BuildRequires:	i2c-devel
BuildRequires:	genders-devel
BuildRequires:	pkgconfig(gdlib) >= 2.0.5
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	libtool-devel
BuildRequires:	pkgconfig(libusb)
BuildRequires:	net-snmp-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig
BuildRequires:	pkgconfig(libpowerman)
BuildRequires:	tcp_wrappers-devel
BuildRequires:	pkgconfig(xpm)
BuildRequires:	pkgconfig(avahi-core)
BuildRequires:	pkgconfig(avahi-client)
BuildRequires:	pkgconfig(libfreeipmi)
%if %{build_neonxml}
BuildRequires:	pkgconfig(neon) >= 0.25.0
%endif
%if %{build_doc}
BuildRequires:	dblatex
BuildRequires:	asciidoc >= 8.6.3
%endif

%description
These programs are part of a developing project to monitor the assortment of
UPSes that are found out there in the field. Many models have serial ports of
some kind that allow some form of state checking. This capability has been
harnessed where possible to allow for safe shutdowns, live status tracking on
web pages, and more.

This package includes the client utilities that are required to monitor a UPS
that the client host is powered from - either connected directly via a serial
port (in which case the nut-server package needs to be installed on this
machine) or across the network (where another host on the network monitors the
UPS via serial cable and runs the main nut package to allow clients to see the
information).

%package -n	%{libname}
Summary:	Network UPS Tools Client Utilities library
Group:          System/Libraries

%description -n	%{libname}
These programs are part of a developing project to monitor the assortment of
UPSes that are found out there in the field. Many models have serial ports of
some kind that allow some form of state checking. This capability has been
harnessed where possible to allow for safe shutdowns, live status tracking on
web pages, and more.

This package contains the shared libraries for NUT client applications.

%package	server
Summary:	Network UPS Tools server
Group:		System/Servers
Requires:	nut >= %{epoch}:%{version}-%{release}
Requires(pre):	nut >= %{epoch}:%{version}-%{release}
Requires(pre):	rpm-helper >= 0.8
Requires:	tcp_wrappers

%description	server
These programs are part of a developing project to monitor the assortment of
UPSes that are found out there in the field. Many models have serial ports of
some kind that allow some form of state checking. This capability has been
harnessed where possible to allow for safe shutdowns, live status tracking on
web pages, and more.

This package is the main NUT upsd daemon and the associated per-UPS-model
drivers which talk to the UPSes. You also need to install the base NUT package.

%package	cgi
Summary:	CGI utils for NUT
Group:		Monitoring
Requires:	apache
Conflicts:	apcupsd

%description	cgi
These programs are part of a developing project to monitor the assortment of
UPSes that are found out there in the field. Many models have serial ports of
some kind that allow some form of state checking. This capability has been
harnessed where possible to allow for safe shutdowns, live status tracking on
web pages, and more.

This package adds the web CGI programs. These can be installed on a separate
machine to the rest of the NUT package.

%package	devel
Summary:	Development for NUT Client
Group:		Development/C
Requires(pre):	rpm-helper >= 0.8
Requires:	%{libname} >= %{epoch}:%{version}

%description	devel
These programs are part of a developing project to monitor the assortment of
UPSes that are found out there in the field. Many models have serial ports of
some kind that allow some form of state checking. This capability has been
harnessed where possible to allow for safe shutdowns, live status tracking on
web pages, and more.

This package contains the development header files and libraries
necessary to develop NUT client applications.

%prep

%setup -q
%patch90 -p0 -b .upsset.conf
%patch91 -p1 -b .mdv_conf
%patch92 -p0 
#%patch94 -p1 -b .fixbuild
%patch1 -p1
#%patch3 -p1
#%patch5 -p1

# instead of a patch
perl -pi -e "s|/cgi-bin/nut/||g" data/html/*.html*

%build
# this takes care of rpath
#libtoolize --copy --force; aclocal -I m4; autoconf; automake --foreign --add-missing --copy

%serverbuild

autoreconf -i
%configure \
    --with-all \
    --with-libltdl \
    --without-hal \
    --without-modbus \
    --with-cgi \
    --disable-static \
    --sysconfdir=%{_sysconfdir}/ups \
%if %{build_neonxml}
    --with-neon \
%endif
%if %{build_doc}
    --with-doc \
%endif
    --with-statepath=/var/state/ups \
    --with-drvpath=%{_sbindir} \
    --with-cgipath=%{_libdir}/nut \
    --with-htmlpath=%{_libdir}/nut \
    --with-pidpath=/run/nut \
    --with-port=3493 \
    --with-user=ups \
    --with-group=ups \
    --with-systemdsystemunitdir=%{_unitdir} \
    --with-pkgconfig-dir=%{_libdir}/pkgconfig \
    --with-udev-dir=%{_prefix}/lib/udev

%{SOURCE4} >>include/config.h

%make_build

%install
%make_install

install -d %{buildroot}/var/state/ups

# move the *.sample config files to their real locations
for file in %{buildroot}%{_sysconfdir}/ups/*.sample; do
    mv $file %{buildroot}%{_sysconfdir}/ups/`basename $file .sample`
done

perl -pi \
    -e 's/# RUN_AS_USER nutmon/RUN_AS_USER ups/g' \
    %{buildroot}%{_sysconfdir}/ups/upsmon.conf

# restrict some permissions on configuration files
chmod 640 %{buildroot}%{_sysconfdir}/ups/upssched.conf
chmod 640 %{buildroot}%{_sysconfdir}/ups/upsmon.conf
chmod 640 %{buildroot}%{_sysconfdir}/ups/upsd.users
chmod 640 %{buildroot}%{_sysconfdir}/ups/upsd.conf


install -D -m 644 %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/nut-client.conf

cp -af data/driver.list docs/

# udev usb ups stuff
mv %{buildroot}/%{_prefix}/lib/udev/rules.d/62-nut-usbups.rules \
    %{buildroot}/%{_prefix}/lib/udev/rules.d/70-nut-usbups.rules
mv %{buildroot}/%{_prefix}/lib/udev/rules.d/52-nut-ipmipsu.rules \
    %{buildroot}/%{_prefix}/lib/udev/rules.d/70-nut-ipmipsu.rules

# fix access config files
install -d %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/%{name}-cgi.conf << EOF

Alias /nut %{_libdir}/nut

<Directory %{_libdir}/nut>
    Require local granted
    AddHandler cgi-script .cgi
    Options +ExecCGI
</Directory>
EOF

# cleanup
rm -f %{buildroot}%{_sysconfdir}/ups/nut.conf
rm -f %{buildroot}%{_datadir}/solaris-init/nut

find %{buildroot} -name '*.la' -delete

%pre
# Create a UPS user
%_pre_useradd ups /var/state/ups /bin/false
%{_sbindir}/usermod -G dialout,tty,usb ups

%preun
# only do this if it is not an upgrade
%_preun_service upsmon

%post
%_post_service upsmon

%postun
# Only do this if it is not an upgrade
if [ ! -f %_sbindir/upsd ]; then
   %_postun_userdel ups
fi

%pre	server
# Create a UPS user. We do not use the buggy macro %_pre_groupadd anymore.
%_pre_useradd ups /var/state/ups /bin/false
%{_sbindir}/usermod -G dialout,tty,usb ups

%preun	server
%_preun_service upsd || :

%post	server
%_post_service upsd || :

%postun	server
# Only do this if it is not an upgrade
if [ ! -f %_sbindir/upsmon ]; then
   %_postun_userdel ups
fi

%files
%doc AUTHORS COPYING ChangeLog MAINTAINERS NEWS README UPGRADING docs
%dir %{_sysconfdir}/ups
%{_unitdir}/nut-monitor.service
%{_tmpfilesdir}/nut-client.conf
%{_tmpfilesdir}/nut-common.tmpfiles
%attr(-,root,ups) %config(noreplace) %{_sysconfdir}/ups/upssched.conf
%attr(-,root,ups) %config(noreplace) %{_sysconfdir}/ups/upsmon.conf
%attr(-,ups,ups) %dir /var/state/ups
%{_bindir}/upsc
%{_bindir}/upscmd
%{_bindir}/nut-scanner
%{_bindir}/upslog
%{_bindir}/upsrw
%{_bindir}/upssched-cmd
%{_sbindir}/upsmon
%{_sbindir}/upssched
%{_mandir}/man5/upsmon.conf.5*
%{_mandir}/man5/upssched.conf.5*
%{_mandir}/man8/upsc.8*
%{_mandir}/man8/upscmd.8*
%{_mandir}/man8/upsrw.8*
%{_mandir}/man8/upslog.8*
%{_mandir}/man8/upsmon.8*
%{_mandir}/man8/upssched.8*
%{_mandir}/man8/upsset.cgi.8*
%{_prefix}/lib/systemd/system-shutdown/nutshutdown

%files -n %{libname}
%{_libdir}/*.so.*

%files server
%{_sbindir}/upsd
%{_unitdir}/nut-driver@.service
%{_unitdir}/nut-driver-enumerator.path
%{_unitdir}/nut-driver-enumerator.service
%{_unitdir}/nut-driver.target
%{_unitdir}/nut.target
%{_unitdir}/nut-server.service
%config(noreplace) %{_sysconfdir}/ups/ups.conf
%attr(-,root,ups) %config(noreplace) %{_sysconfdir}/ups/upsd.users
%attr(-,root,ups) %config(noreplace) %{_sysconfdir}/ups/upsd.conf
%_udevrulesdir/70-nut-usbups.rules
%_udevrulesdir/70-nut-ipmipsu.rules
%{_sbindir}/al175
%{_sbindir}/apcsmart
%{_sbindir}/apcsmart-old
%{_sbindir}/apcupsd-ups
%{_sbindir}/asem
%{_sbindir}/bcmxcp
%{_sbindir}/bcmxcp_usb
%{_sbindir}/belkin
%{_sbindir}/belkinunv
%{_sbindir}/bestfcom
%{_sbindir}/bestfortress
%{_sbindir}/bestuferrups
%{_sbindir}/bestups
%{_sbindir}/blazer_ser
%{_sbindir}/blazer_usb
%{_sbindir}/clone
%{_sbindir}/clone-outlet
%{_sbindir}/dummy-ups
%{_sbindir}/etapro
%{_sbindir}/everups
%{_sbindir}/gamatronic
%{_sbindir}/genericups
%{_sbindir}/isbmex
%{_sbindir}/ivtscd
%{_sbindir}/liebert
%{_sbindir}/liebert-esp2
%{_sbindir}/masterguard
%{_sbindir}/metasys
%{_sbindir}/mge-shut
%{_sbindir}/mge-utalk
%{_sbindir}/microdowell
%{_sbindir}/microsol-apc
%if %{build_neonxml}
%{_sbindir}/netxml-ups
%endif
%{_sbindir}/nutdrv_atcl_usb
%{_sbindir}/nutdrv_qx
%{_sbindir}/nutdrv_siemens-sitop
%{_sbindir}/nut-ipmipsu
%{_sbindir}/oneac
%{_sbindir}/optiups
%{_sbindir}/pijuice
%{_sbindir}/powercom
%{_sbindir}/powerman-pdu
%{_sbindir}/powerpanel
%{_sbindir}/rhino
%{_sbindir}/richcomm_usb
%{_sbindir}/riello_ser
%{_sbindir}/riello_usb
%{_sbindir}/safenet
%{_sbindir}/skel
%{_sbindir}/snmp-ups
%{_sbindir}/solis
%{_sbindir}/tripplite
%{_sbindir}/tripplitesu
%{_sbindir}/tripplite_usb
%{_sbindir}/upscode2
%{_sbindir}/upsdrvctl
%{_sbindir}/upsdrvsvcctl
%{_sbindir}/usbhid-ups
%{_sbindir}/victronups
%{_libexecdir}/nut-driver-enumerator.sh
%{_datadir}/cmdvartab
%{_datadir}/driver.list
%{_mandir}/man3/libnutclient.3*
%{_mandir}/man3/libnutclient_commands.3*
%{_mandir}/man3/libnutclient_devices.3*
%{_mandir}/man3/libnutclient_general.3*
%{_mandir}/man3/libnutclient_misc.3*
%{_mandir}/man3/libnutclient_tcp.3*
%{_mandir}/man3/libnutclient_variables.3*
%{_mandir}/man3/nutclient_authenticate.3*
%{_mandir}/man3/nutclient_destroy.3*
%{_mandir}/man3/nutclient_device_forced_shutdown.3*
%{_mandir}/man3/nutclient_device_login.3*
%{_mandir}/man3/nutclient_device_master.3*
%{_mandir}/man3/nutclient_execute_device_command.3*
%{_mandir}/man3/nutclient_get_device_command_description.3*
%{_mandir}/man3/nutclient_get_device_commands.3*
%{_mandir}/man3/nutclient_get_device_description.3*
%{_mandir}/man3/nutclient_get_device_num_logins.3*
%{_mandir}/man3/nutclient_get_device_rw_variables.3*
%{_mandir}/man3/nutclient_get_device_variable_description.3*
%{_mandir}/man3/nutclient_get_device_variable_values.3*
%{_mandir}/man3/nutclient_get_device_variables.3*
%{_mandir}/man3/nutclient_get_devices.3*
%{_mandir}/man3/nutclient_has_device.3*
%{_mandir}/man3/nutclient_has_device_command.3*
%{_mandir}/man3/nutclient_has_device_variable.3*
%{_mandir}/man3/nutclient_logout.3*
%{_mandir}/man3/nutclient_set_device_variable_value.3*
%{_mandir}/man3/nutclient_set_device_variable_values.3*
%{_mandir}/man3/nutclient_tcp_create_client.3*
%{_mandir}/man3/nutclient_tcp_disconnect.3*
%{_mandir}/man3/nutclient_tcp_get_timeout.3*
%{_mandir}/man3/nutclient_tcp_is_connected.3*
%{_mandir}/man3/nutclient_tcp_reconnect.3*
%{_mandir}/man3/nutclient_tcp_set_timeout.3*
%{_mandir}/man3/nutscan.3*
%{_mandir}/man3/nutscan_add_device_to_device.3*
%{_mandir}/man3/nutscan_add_option_to_device.3*
%{_mandir}/man3/nutscan_cidr_to_ip.3*
%{_mandir}/man3/nutscan_display_parsable.3*
%{_mandir}/man3/nutscan_display_ups_conf.3*
%{_mandir}/man3/nutscan_free_device.3*
%{_mandir}/man3/nutscan_init.3*
%{_mandir}/man3/nutscan_get_serial_ports_list.3*
%{_mandir}/man3/nutscan_new_device.3*
%{_mandir}/man3/nutscan_scan_avahi.3*
%{_mandir}/man3/nutscan_scan_eaton_serial.3*
%{_mandir}/man3/nutscan_scan_ipmi.3*
%{_mandir}/man3/nutscan_scan_nut.3*
%{_mandir}/man3/nutscan_scan_snmp.3*
%{_mandir}/man3/nutscan_scan_usb.3*
%{_mandir}/man3/nutscan_scan_xml_http_range.3*
%{_mandir}/man5/nut.conf.5*
%{_mandir}/man5/ups.conf.5*
%{_mandir}/man5/upsd.conf.5*
%{_mandir}/man5/upsd.users.5*
%{_mandir}/man8/al175.8*
%{_mandir}/man8/apcsmart.8*
%{_mandir}/man8/apcsmart-old.8*
%{_mandir}/man8/apcupsd-ups.8*
%{_mandir}/man8/asem.8*
%{_mandir}/man8/bcmxcp.8*
%{_mandir}/man8/bcmxcp_usb.8*
%{_mandir}/man8/belkin.8*
%{_mandir}/man8/belkinunv.8*
%{_mandir}/man8/bestfcom.8*
%{_mandir}/man8/bestfortress.8*
%{_mandir}/man8/bestuferrups.8*
%{_mandir}/man8/bestups.8*
%{_mandir}/man8/blazer_ser.8*
%{_mandir}/man8/blazer_usb.8*
%{_mandir}/man8/clone.8*
%{_mandir}/man8/dummy-ups.8*
%{_mandir}/man8/etapro.8*
%{_mandir}/man8/everups.8*
%{_mandir}/man8/gamatronic.8*
%{_mandir}/man8/genericups.8*
%{_mandir}/man8/isbmex.8*
%{_mandir}/man8/ivtscd.8*
%{_mandir}/man8/liebert.8*
%{_mandir}/man8/liebert-esp2.8*
%{_mandir}/man8/masterguard.8*
%{_mandir}/man8/metasys.8*
%{_mandir}/man8/mge-shut.8*
%{_mandir}/man8/mge-utalk.8*
%{_mandir}/man8/microdowell.8*
%{_mandir}/man8/microsol-apc.8*
%{_mandir}/man8/nut-driver-enumerator.8*
%{_mandir}/man8/nutdrv_atcl_usb.8*
%{_mandir}/man8/nutdrv_qx.8*
%{_mandir}/man8/nutdrv_siemens_sitop.8*
%{_mandir}/man8/nut-ipmipsu.8*
%{_mandir}/man8/nut-recorder.8*
%{_mandir}/man8/nut-scanner.8*
%{_mandir}/man8/nutupsdrv.8*
%{_mandir}/man8/oneac.8*
%{_mandir}/man8/optiups.8*
%{_mandir}/man8/pijuice.8*
%{_mandir}/man8/powercom.8*
%{_mandir}/man8/powerman-pdu.8*
%{_mandir}/man8/powerpanel.8*
%{_mandir}/man8/rhino.8*
%{_mandir}/man8/richcomm_usb.8*
%{_mandir}/man8/riello_ser.8*
%{_mandir}/man8/riello_usb.8*
%{_mandir}/man8/safenet.8*
%{_mandir}/man8/snmp-ups.8*
%{_mandir}/man8/solis.8*
%{_mandir}/man8/tripplite.8*
%{_mandir}/man8/tripplitesu.8*
%{_mandir}/man8/tripplite_usb.8*
%{_mandir}/man8/upscode2.8*
%{_mandir}/man8/upsd.8*
%{_mandir}/man8/upsdrvctl.8*
%{_mandir}/man8/upsdrvsvcctl.8*
%{_mandir}/man8/usbhid-ups.8*
%{_mandir}/man8/victronups.8*
%if %{build_neonxml}
%{_mandir}/man8/netxml-ups.8*
%endif

%files cgi
%config(noreplace) %{_sysconfdir}/ups/hosts.conf
%config(noreplace) %{_sysconfdir}/ups/upsset.conf
%config(noreplace) %{_sysconfdir}/ups/upsstats.html
%config(noreplace) %{_sysconfdir}/ups/upsstats-single.html
%config(noreplace) %{_webappconfdir}/%{name}-cgi.conf
%{_libdir}/nut
%{_mandir}/man5/hosts.conf.5*
%{_mandir}/man5/upsstats.html.5*
%{_mandir}/man5/upsset.conf.5*
%{_mandir}/man8/upsimage.cgi.8*
%{_mandir}/man8/upsset.cgi.8*
%{_mandir}/man8/upsstats.cgi.8*

%files devel
%{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/upscli_*.3*
%{_mandir}/man3/upsclient.3*


%changelog
* Fri Oct 28 2022 danf <danf> 1:2.8.0-1.mga9
+ Revision: 1899874
- Update to ver. 2.8.0
- rediffed patches & removed obsolete ones
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Nov 03 2020 akien <akien> 1:2.7.4-6.mga8
+ Revision: 1642024
- Rebuild for new libnetsnmp

* Fri Feb 14 2020 umeabot <umeabot> 1:2.7.4-5.mga8
+ Revision: 1521654
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1:2.7.4-4.mga7
+ Revision: 1346029
- rebuild for net-snmp

* Sun Sep 23 2018 umeabot <umeabot> 1:2.7.4-3.mga7
+ Revision: 1299816
- Mageia 7 Mass Rebuild

* Tue Mar 27 2018 kekepower <kekepower> 1:2.7.4-2.mga7
+ Revision: 1212857
- Rebuild for new freeipmi

* Thu Oct 05 2017 mrambo3501 <mrambo3501> 1:2.7.4-1.mga7
+ Revision: 1169255
- version 2.7.4
- rediffed mageia patches 91 and 93
- picked up rediffed fedora patches for patches 3 and 5
- dropped fedora patches 4 and 6 removed from fc25
- added an upsteam patch which fixes a build failure

* Fri Sep 08 2017 guillomovitch <guillomovitch> 1:2.6.5-19.mga7
+ Revision: 1151887
- rebuild with openssl 1.1

* Fri Mar 31 2017 mrambo3501 <mrambo3501> 1:2.6.5-18.mga6
+ Revision: 1095477
- add patch to change nut-driver.service setting (mga#14687)

* Thu Mar 03 2016 umeabot <umeabot> 1:2.6.5-17.mga6
+ Revision: 983845
- Rebuild for openssl

* Tue Feb 09 2016 umeabot <umeabot> 1:2.6.5-16.mga6
+ Revision: 952310
- Mageia 6 Mass Rebuild

* Mon Feb 16 2015 oden <oden> 1:2.6.5-15.mga5
+ Revision: 815159
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 1:2.6.5-14.mga5
+ Revision: 750431
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:2.6.5-13.mga5
+ Revision: 682954
- Mageia 5 Mass Rebuild

* Sat Jul 05 2014 pterjan <pterjan> 1:2.6.5-12.mga5
+ Revision: 643761
- Replace libusb*-devel BuildRequires by better ones

* Thu May 08 2014 tv <tv> 1:2.6.5-11.mga5
+ Revision: 621281
- add more patches from FC for devel fix
- add more patches from FC for devel fix
- do not depend on devel files (rhbz#838139, mga#13320)

* Mon Mar 10 2014 fwang <fwang> 1:2.6.5-10.mga5
+ Revision: 601668
- use new file layout

* Mon Mar 10 2014 fwang <fwang> 1:2.6.5-9.mga5
+ Revision: 601663
- rebuild for new freeipmi

* Tue Oct 22 2013 umeabot <umeabot> 1:2.6.5-8.mga4
+ Revision: 541363
- Mageia 4 Mass Rebuild

* Sat Oct 12 2013 fwang <fwang> 1:2.6.5-7.mga4
+ Revision: 495723
- rebuild for new freeipmi

* Mon May 27 2013 oden <oden> 1:2.6.5-6.mga4
+ Revision: 428763
- rebuilt against libgd.so.3

* Wed Jan 23 2013 fwang <fwang> 1:2.6.5-5.mga3
+ Revision: 391295
- update rpm group

* Sat Jan 12 2013 umeabot <umeabot> 1:2.6.5-4.mga3
+ Revision: 361082
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 pterjan <pterjan> 1:2.6.5-3.mga3
+ Revision: 324541
- Add Fedora patch to build with recent freeipmi
+ luigiwalser <luigiwalser>
- fix owner of /run/nut in tmpfiles config
- replace undefined macro
+ fwang <fwang>
- rebuild for new freeipmi

* Thu Sep 06 2012 guillomovitch <guillomovitch> 1:2.6.5-1.mga3
+ Revision: 288859
- install www content under %%{_libdir}/nut, and make its configuration compatible with apache 2.4
- hardcode user
- use /run/nut instead of /var/run/nut
- use relevant macro for webapp configuration directory
- cleanup files section
- drop sysinit support
- new version
- add systemd support
- add avahi and ipmi support
- drop hal support
- use /lib/udev instead of /etc/udev for udev rules

* Thu Jul 19 2012 fwang <fwang> 1:2.6.4-2.mga3
+ Revision: 272553
- drop hal support as it is not enabled by default

* Thu Jun 14 2012 luigiwalser <luigiwalser> 1:2.6.4-1.mga3
+ Revision: 260685
- add apcsmart-old to files list
- do not try to build tools that do not build
- 2.6.4 (fix CVE-2012-2944)

* Wed Sep 07 2011 tv <tv> 1:2.6.1-1.mga2
+ Revision: 140359
- fix missing LSB keywords
- new release
+ guillomovitch <guillomovitch>
- rebuild for latest net-snmp

* Thu Mar 03 2011 ennael <ennael> 1:2.6.0-2.mga1
+ Revision: 63404
- add mageia in list
- clean spec file
- imported package nut

